G.useRemoteInput = false and (Application:GetPlatformName() == "WIN32DX9" or Application:GetPlatformName() == "WIN32DX11")

-- our marble
function OnAfterSceneLoaded(self)

  if G.useRemoteInput then  
    RemoteInput:StartServer('RemoteGUI')
    RemoteInput:InitEmulatedDevices()
    RemoteInput:DebugDrawTouchPoints(Vision.VColorRef(255,0,0))
    
    end
  Debug:Enable(true)

  if Application:IsInEditor() and Application:GetEditorMode() ~= Vision.EDITOR_PLAY then
    self:SetThinkFunctionStatus(false)
    Debug:PrintLine("Use 'Play the Game' when starting in editor!")
    Debug:Log("Use 'Play the Game' when starting in editor!")
    return
  end

  self.RigidBody = self:GetComponentOfType("vHavokRigidBody")
  Vision.Assert(self.RigidBody~=nil, "Rigid Body is missing!")
  self.Camera = Game:GetCamera()
--  self.ContactSound = Fmod:GetSound("BigThump")
--  self.HitSound = Fmod:GetSound("HitSound")

  self.Platform = Application:GetPlatformName()
  self.JumpForce = 800000
  if G.useRemoteInput or self.Platform == "ANDROID" or self.Platform == "IOS" then
    self.ForceScale = 8000
    self.InputScaleX = 3
    self.InputScaleY = 3
  else
    self.ForceScale = 8000
    self.InputScaleX = 3
    self.InputScaleY = -3
  end

  -- setup input for multiple platforms
  local x,y = Screen:GetViewportSize()
  self.map = Input:CreateMap("ScriptInput")
  self.map:MapTrigger("Jump", {0,0,x,y},  "CT_TOUCH_ANY", {once = true})
  self.map:MapTrigger("X",    "MOTION",   "CT_MOTION_ACCELERATION_X",{ deadzone = 0.10})
  self.map:MapTrigger("Y",    "MOTION",   "CT_MOTION_ACCELERATION_Y",{ deadzone = 0.10})

  if not G.useRemoteInput then
    self.map:MapTrigger("Jump", "PAD1",     "CT_PAD_X", {once = true })
    self.map:MapTrigger("X",    "PAD1",     "CT_PAD_LEFT_THUMB_STICK_LEFT", "CT_PAD_LEFT_THUMB_STICK_RIGHT", { deadzone = 0.25})
    self.map:MapTrigger("Y",    "PAD1",     "CT_PAD_LEFT_THUMB_STICK_UP", "CT_PAD_LEFT_THUMB_STICK_DOWN", { deadzone = 0.25 })
  end
  
  end

function OnBeforeSceneUnloaded(self)
  Input:DestroyMap(self.map)
  self.map = nil
  if useRemoteInput then
    RemoteInput:StopServer()
    RemoteInput:DeinitEmulatedDevices()
  end
end




function OnThink(self)
  local timeDiff = Timer:GetTimeDiff()

  if self.map:GetTrigger("Jump") > 0 then
    local jump = Vision.hkvVec3(0,0,self.JumpForce)
    self.RigidBody:ApplyForce(jump, timeDiff)
  else
    local dx = self.map:GetTrigger("X")
    local dy = self.map:GetTrigger("Y")
    
      --Debug:PrintAt(250,300, "dx: "..dx, Vision.V_RGBA_WHITE, self.FontPath)
      --Debug:PrintAt(250,320, "dy: "..dy, Vision.V_RGBA_WHITE, self.FontPath)    

    local direction = Vision.hkvVec3(dx*self.InputScaleX,0,dy*self.InputScaleY)
    local world = self.Camera:GetCameraToWorldRotation()
    direction = world:transformDirection(direction)
    local force = Vision.hkvVec3(direction.x*self.ForceScale,direction.y*self.ForceScale,0)
    self.RigidBody:ApplyForce(force, timeDiff)
  end
end
















-- info fields: HitPoint, HitNormal, Force, RelativeVelocity,
--              ColliderType, ColliderObject (maybe nil)

function OnCollision(self, info)
  if info.ColliderObject ~= nil then
    if info.RelativeVelocity<0 then
      info.RelativeVelocity = -info.RelativeVelocity
    end
    if info.RelativeVelocity>250 then
      if info.RelativeVelocity > 800 then
        info.RelativeVelocity = 800
      end
--      if info.ColliderType == "Mesh" then  
--        self.ContactSound:SetVolume((info.RelativeVelocity)/800)
--        self.ContactSound:Play()
--      end
--      if info.ColliderType == "Entity" then  
--        self.HitSound:SetVolume((info.RelativeVelocity)/800)
--        self.HitSound:Play()
--      end
    end
  end
end


